@@ -87,6 +87,8 @@ public int index(){
 }
 
 public ArraySeq withMeta(IPersistentMap meta){
+	if(meta() == meta)
+		return this;
 	return new ArraySeq(meta, array, i);
 }
 
@@ -171,6 +173,8 @@ static public class ArraySeq_int extends ASeq implements IndexedSeq, IReduce{
 	}
 
 	public ArraySeq_int withMeta(IPersistentMap meta){
+		if(meta() == meta)
+			return this;
 		return new ArraySeq_int(meta, array, i);
 	}
 
@@ -249,6 +253,8 @@ static public class ArraySeq_float extends ASeq implements IndexedSeq, IReduce{
 	}
 
 	public ArraySeq_float withMeta(IPersistentMap meta){
+		if(meta() == meta)
+			return this;
 		return new ArraySeq_float(meta, array, i);
 	}
 
@@ -324,6 +330,8 @@ static public class ArraySeq_double extends ASeq implements IndexedSeq, IReduce{
 	}
 
 	public ArraySeq_double withMeta(IPersistentMap meta){
+		if(meta() == meta)
+			return this;
 		return new ArraySeq_double(meta, array, i);
 	}
 
@@ -401,6 +409,8 @@ static public class ArraySeq_long extends ASeq implements IndexedSeq, IReduce{
 	}
 
 	public ArraySeq_long withMeta(IPersistentMap meta){
+		if(meta() == meta)
+			return this;
 		return new ArraySeq_long(meta, array, i);
 	}
 
@@ -478,6 +488,8 @@ static public class ArraySeq_byte extends ASeq implements IndexedSeq, IReduce{
 	}
 
 	public ArraySeq_byte withMeta(IPersistentMap meta){
+		if(meta() == meta)
+			return this;
 		return new ArraySeq_byte(meta, array, i);
 	}
 
@@ -563,6 +575,8 @@ static public class ArraySeq_char extends ASeq implements IndexedSeq, IReduce{
 	}
 
 	public ArraySeq_char withMeta(IPersistentMap meta){
+		if(meta() == meta)
+			return this;
 		return new ArraySeq_char(meta, array, i);
 	}
 
@@ -648,6 +662,8 @@ static public class ArraySeq_short extends ASeq implements IndexedSeq, IReduce{
 	}
 
 	public ArraySeq_short withMeta(IPersistentMap meta){
+		if(meta() == meta)
+			return this;
 		return new ArraySeq_short(meta, array, i);
 	}
 
@@ -733,6 +749,8 @@ static public class ArraySeq_boolean extends ASeq implements IndexedSeq, IReduce
 	}
 
 	public ArraySeq_boolean withMeta(IPersistentMap meta){
+		if(meta() == meta)
+			return this;
 		return new ArraySeq_boolean(meta, array, i);
 	}
 
